@@ -14,7 +14,7 @@ use Carp qw(croak);
 # Globals and constants
 
 use vars qw($VERSION);
-$VERSION = sprintf('%d.%02d', q$Revision: 1.10 $ =~ /(\d+)/g);
+$VERSION = sprintf('%d.%02d', q$Revision: 1.11 $ =~ /(\d+)/g);
 
 
 
@@ -22,10 +22,10 @@ $VERSION = sprintf('%d.%02d', q$Revision: 1.10 $ =~ /(\d+)/g);
 # Public methods
 
 sub new {
-        # Check we're being called correctly with a class name
-        ref(my $class = shift) && croak 'Class name required';
-        my %args = @_;
-        my $self = { };
+	# Check we're being called correctly with a class name
+	ref(my $class = shift) && croak 'Class name required';
+	my %args = @_;
+	my $self = { };
 
 	# Defaults
 	$args{fstab} ||= '/etc/vfstab';
@@ -62,6 +62,7 @@ sub new {
 	if ($mtab->open($args{mtab})) {
 		while (<$mtab>) {
 			next if /^\s*#/;
+			next if /^\s*$/;
 			my @vals = split(/\s+/, $_);
 			delete $self->{$vals[1]}->{unmounted} if exists $self->{$vals[1]}->{unmounted};
 			$self->{$vals[1]}->{mounted} = 1;
@@ -75,9 +76,9 @@ sub new {
 		croak "Unable to open mtab file ($args{mtab})\n";
 	}
 
-        # Bless and return
-        bless($self,$class);
-        return $self;
+	# Bless and return
+	bless($self,$class);
+	return $self;
 }
 
 1;
@@ -94,7 +95,7 @@ Sys::Filesystem::Solaris - Return Solaris filesystem information to Sys::Filesys
 
 =head1 VERSION
 
-$Revision: 1.10 $
+$Revision: 1.11 $
 
 =head1 FILESYSTEM PROPERTIES
 
@@ -157,6 +158,9 @@ $Author: nicolaw $
 =head1 CHANGELOG
 
     $Log: Solaris.pm,v $
+    Revision 1.11  2005/12/02 16:05:04  nicolaw
+    Fixed tabulation, ^M's and skipping of empty lines in footab files
+
     Revision 1.10  2004/10/06 15:27:37  nicolaw
     Type in POD
 
