@@ -14,7 +14,7 @@ use Carp qw(croak);
 # Globals and constants
 
 use vars qw($VERSION);
-$VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /(\d+)/g);
+$VERSION = sprintf('%d.%02d', q$Revision: 1.3 $ =~ /(\d+)/g);
 
 
 
@@ -22,10 +22,10 @@ $VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /(\d+)/g);
 # Public methods
 
 sub new {
-        # Check we're being called correctly with a class name
-        ref(my $class = shift) && croak 'Class name required';
-        my %args = @_;
-        my $self = { };
+	# Check we're being called correctly with a class name
+	ref(my $class = shift) && croak 'Class name required';
+	my %args = @_;
+	my $self = { };
 
 	# Defaults
 	$args{fstab} ||= '/etc/fstab';
@@ -40,6 +40,8 @@ sub new {
 	if ($fstab->open($args{fstab})) {
 		while (<$fstab>) {
 			next if /^\s*#/;
+			next if /^\s*$/;
+
 			my @vals = split(/\s+/, $_);
 			$self->{$vals[1]}->{mount_point} = $vals[1];
 			$self->{$vals[1]}->{device} = $vals[0];
@@ -57,6 +59,7 @@ sub new {
 	if ($mtab->open($args{mtab})) {
 		while (<$mtab>) {
 			next if /^\s*#/;
+			next if /^\s*$/;
 			my @vals = split(/\s+/, $_);
 			delete $self->{$vals[1]}->{unmounted} if exists $self->{$vals[1]}->{unmounted};
 			$self->{$vals[1]}->{mounted} = 1;
@@ -69,9 +72,9 @@ sub new {
 		$mtab->close;
 	}
 
-        # Bless and return
-        bless($self,$class);
-        return $self;
+	# Bless and return
+	bless($self,$class);
+	return $self;
 }
 
 1;
@@ -84,6 +87,9 @@ __END__
 # CVS changelog
 
 $Log: Unix.pm,v $
+Revision 1.3  2005/12/02 16:05:04  nicolaw
+Fixed tabulation, ^M's and skipping of empty lines in footab files
+
 Revision 1.2  2004/09/28 16:43:21  nicolaw
 *** empty log message ***
 
